@@ -167,7 +167,7 @@ class Config:
             raise e
 
 
-class NodePublicConfig(Config):
+class NodeLearningConfig(Config):
     # noinspection PyUnresolvedReferences
     """Overloads :`Config`, corresponding to configuration of a node that can be accessed by the
     central server.
@@ -175,7 +175,7 @@ class NodePublicConfig(Config):
     Used by `ifra.node.Node` and `ifra.central_server.NodeGate`
 
     Overloads \_\_eq\_\_ to allow for node configuration comparison. Two configurations are equal if all their
-    configuration values are equal, except *node_model_path* and *central_model_path* that can be different.
+    configuration values are equal, except *node_models_path* and *central_model_path* that can be different.
 
     Attributes
     ----------
@@ -201,9 +201,9 @@ class NodePublicConfig(Config):
     max_depth: int
         Maximum depth of the decision tree to use in the model
     remember_activation: bool
-        If True, the ruleset created by the node will remember its activation (logical OR of all its rules)
+        If True, the model created by the node will remember its activation (logical OR of all its rules)
     stack_activation: bool
-        If True, the ruleset created by the node will stack its rules' activation vectors into a np.ndarray (watch out
+        If True, the model created by the node will stack its rules' activation vectors into a np.ndarray (watch out
         for memory overload)
     plot_data: bool
         If True, nodes will plot distributions of their data in the same directory they found the said data.
@@ -212,25 +212,28 @@ class NodePublicConfig(Config):
     get_leaf: bool
         If True, will only consider the leaf ofthe tree to create rules. If False, every node of the tree will also be
         a rule.
-    node_model_path: TransparentPath
-        Path where the node is supposed to write its model. Should point to a csv file to which the aggregator has
+    node_models_path: TransparentPath
+        Path where all nodes are supposed to write their model. Should point to a directory to which the aggregator has
         access.
-    node_model_path_fs: TransparentPath
-        File system to use for local model file. Can be 'gcs', 'local' or "". If not specified, the json
-        file should still contain the key *node_model_path_fs*, but with value "".
+    node_models_path_fs: TransparentPath
+        File system to use for node models directory. Can be 'gcs', 'local' or "". If not specified, the json
+        file should still contain the key *node_models_path_fs*, but with value "".
     id: Union[None, int, str]
         Name or number of the node. Can not be "".
     dataprep: Union[str]
         Name of the dataprep to use. Can be "" or one of:\n
           * BinFeaturesDataPrep (see `ifra.datapreps.BinFeaturesDataPrep`)\n
-        If not specified, will be set by central server. If not specified, the json  file should still contain the key
-        *dataprep*, but with value "".
+        If not specified, the json  file should still contain the key *dataprep*, but with value "".
     dataprep_kwargs: dict
         Keyword arguments for the `ifra.datapreps.Dataprep` init. If not specified, the json file should still contain
         the key *dataprep_kwargs*, but with value "".
+    train_test_split: Union[None, str]
+        Name of the dataprep to use. Can be "" or one of:\n
+          * nothing yet :) \n
+        If not specified, the json  file should still contain the key *dataprep*, but with value "".
     fitter: str
         Fitter to use. Can be one of :\n
-          * decisiontree_fitter (see `ifra.fitter.DecisionTreeFitter`)\n
+          * decisiontree_fitter (see `ifra.fitters.DecisionTreeFitter`)\n
     fitter_kwargs: dict
         Keyword arguments for the `ifra.fitters.Fitter` init. If not specified, the json file should still contain the
         key *fitter_kwargs*, but with value "".
@@ -268,10 +271,11 @@ class NodePublicConfig(Config):
         "stack_activation",
         "plot_data",
         "get_leaf",
-        "node_model_path",
-        "node_model_path_fs",
+        "node_models_path",
+        "node_models_path_fs",
         "dataprep",
         "dataprep_kwargs",
+        "train_test_split",
         "id",
         "fitter",
         "fitter_kwargs",
@@ -282,28 +286,27 @@ class NodePublicConfig(Config):
         "emitter_path",
         "emitter_path_fs",
         "central_model_path",
-        "central_model_path_fs"
+        "central_model_path_fs",
     ]
 
     def __eq__(self, other):
-        if not isinstance(other, NodePublicConfig):
+        if not isinstance(other, NodeLearningConfig):
             return False
-        for key in NodePublicConfig.EXPECTED_CONFIGS:
+        for key in NodeLearningConfig.EXPECTED_CONFIGS:
             # Those parameters can be different
             if (
-                    key == "emitter_path"
-                    or key == "node_model_path"
-                    or key == "id"
-                    or key.endswith("_fs")
-                    or key.endswith("_fss")
-                    or key == "plot_data"
+                key == "emitter_path"
+                or key == "id"
+                or (key.endswith("_fs") and key != "node_models_path_fs")
+                or key == "plot_data"
             ):
                 continue
             if key not in self.configs and key not in other.configs:
                 continue
             if key == "thresholds_path":  # Can be either both "", or both not "" and different or both "" and equal
-                if (self.configs[key] == "" and other.configs[key] == "")\
-                        or (self.configs[key] != "" and other.configs[key] != ""):
+                if (self.configs[key] == "" and other.configs[key] == "") or (
+                    self.configs[key] != "" and other.configs[key] != ""
+                ):
                     continue
             if self.configs[key] != other.configs[key]:
                 return False
@@ -323,11 +326,16 @@ class AggregatorConfig(Config):
     configs: dict
         see `Config`
 
+    node_models_path: TransparentPath
+        Path where all nodes will write their models.
+    node_models_path_fs: TransparentPath
+        File system to use for node models directory. Can be 'gcs', 'local' or "". If not specified, the json
+        file should still contain the key *node_models_path_fs*, but with value "".
     aggregated_model_path: TransparentPath
         Path where the aggregator will save its model after each aggregations. Will also produce one output each
         time the model is updated. Should point to a csv file.
     aggregated_model_path_fs: str
-        File system to use for learning outpout. Can be 'gcs', 'local' or ""
+        File system to use for learning outpout. Can be 'gcs', 'local' or "".
     min_number_of_new_models: int
         Minimum number of nodes that must have prodived a new model to trigger aggregation.
     aggregation: str
@@ -337,13 +345,15 @@ class AggregatorConfig(Config):
         Keyword arguments for the `ifra.aggregations.Aggregation` init. If not specified, the json file should still
         contain the key *aggregation_kwargs*, but with value "".
     emitter_path: TransparentPath
-        Path to emitter json file. See `ifra.messenger.Emitter`
+        Path to emitter json file. See `ifra.messenger.Emitter`.
     emitter_path_fs: TransparentPath
         File system of path to emitter. Can be 'gcs', 'local' or "". If not specified, the json
         file should still contain the key *emitter_path_fs*, but with value "".
     """
 
     EXPECTED_CONFIGS = [
+        "node_models_path",
+        "node_models_path_fs",
         "aggregated_model_path",
         "aggregated_model_path_fs",
         "min_number_of_new_models",
@@ -405,7 +415,7 @@ class NodeDataConfig(Config):
     a dataframe (a single column in the case of the target file).
     The features file should contain one column for EACH FEATURE USED IN THE LEARNING, even if not all of them have data
     in this node. The order of the columns should match the order in
-    `ifra.central_server.NodeGate.NodePublicConfig`'s features_names`.
+    `ifra.central_server.NodeGate.NodeLearningConfig`'s features_names`.
 
     Attributes
     ----------
@@ -432,30 +442,52 @@ class NodeDataConfig(Config):
         File system to use for y file. Can be 'gcs', 'local' or ""
     dataprep_kwargs: dict
         Set by `ifra.node.Node`. Keyword arguments for the dataprep.
-    x_path_to_use: TransparentPath
-        Set by `ifra.node.Node.fit`. Path to the (datapreped and) copied features file used for learning.
-    y_path_to_use: TransparentPath
-        Set by `ifra.node.Node.fit`. Path to the (datapreped and) copied target file used for learning.
+    x_datapreped_path: TransparentPath
+        Set by `ifra.node.Node.fit`. Path to the datapreped features file, before splitting into train/test.
+    y_datapreped_path: TransparentPath
+        Set by `ifra.node.Node.fit`. Path to the datapreped target file, before splitting into train/test.
+    x_train_path: TransparentPath
+        Set by `ifra.test_train_split.TrainTestSplit.split`. Path to the features file to use for testing. Can be None
+        if no split is done.
+    y_train_path: TransparentPath
+        Set by `ifra.test_train_split.TrainTestSplit.split`. Path to the features file to use for testing. Can be None
+        if no split is done.
+    x_test_path: TransparentPath
+        Set by `ifra.test_train_split.TrainTestSplit.split`. Path to the features file to use for testing.
+    y_test_path: TransparentPath
+        Set by `ifra.test_train_split.TrainTestSplit.split`. Path to the target file to use for testing.
     """
 
     EXPECTED_CONFIGS = ["x_path", "y_path", "x_read_kwargs", "y_read_kwargs", "x_path_fs", "y_path_fs"]
-    ADDITIONNAL_CONFIGS = {"dataprep_kwargs": {}, "x_path_to_use": None, "y_path_to_use": None}
+    ADDITIONNAL_CONFIGS = {
+        "dataprep_kwargs": {},
+        "x_datapreped_path": None,
+        "y_datapreped_path": None,
+        "x_train_path": None,
+        "y_train_path": None,
+        "x_test_path": None,
+        "y_test_path": None,
+    }
 
     def __init__(self, path: Optional[Union[str, Path, TransparentPath]] = None):
         super().__init__(path)
 
         if "index_col" in self.x_read_kwargs:
             if self.x_read_kwargs["index_col"] != 0:
-                raise ValueError("If specifying index_col, it should be 0, otherwise you will have problems when saving"
-                                 " intermediate x learning copies")
+                raise ValueError(
+                    "If specifying index_col, it should be 0, otherwise you will have problems when saving"
+                    " intermediate x learning copies"
+                )
         else:
             if self.x.suffix == ".csv":
                 raise ValueError("If x file is a csv, then its read kwargs should contain 'index_col=0'")
 
         if "index_col" in self.y_read_kwargs:
             if self.y_read_kwargs["index_col"] != 0:
-                raise ValueError("If specifying index_col, it should be 0, otherwise you will have problems when saving"
-                                 " intermediate y learning copies")
+                raise ValueError(
+                    "If specifying index_col, it should be 0, otherwise you will have problems when saving"
+                    " intermediate y learning copies"
+                )
         else:
             if self.y.suffix == ".csv":
                 raise ValueError("If y file is a csv, then its read kwargs should contain 'index_col=0'")
