@@ -25,8 +25,8 @@ class DataPrep:
 
     def dataprep(self):
         """Writes the output of the dataprep in `ifra.node.Node`'s *data.x_path* and `ifra.node.Node`'s *data.y_path*
-        parent directories by appending *_to_use* to the files names. Modifies `ifra.node.Node`'s *data.x_path* and
-        `ifra.node.Node`'s *data.y_path* to point to those files.
+        parent directories by appending *_datapreped* to the files names. Modifies `ifra.node.Node`'s
+        *data.x_datapreped_path* and `ifra.node.Node`'s *data.y_datapreped_path* to point to those files.
         """
         x, y = self.dataprep_method(
             self.data.x_path.read(**self.data.x_read_kwargs),
@@ -34,13 +34,11 @@ class DataPrep:
         )
         x_suffix = self.data.x_path.suffix
         y_suffix = self.data.y_path.suffix
-        x_datapreped_path = self.data.x_path.with_suffix("").append("_to_use").with_suffix(x_suffix)
-        y_datapreped_path = self.data.y_path.with_suffix("").append("_to_use").with_suffix(y_suffix)
+        self.data.x_datapreped_path = self.data.x_path.with_suffix("").append("_datapreped").with_suffix(x_suffix)
+        self.data.y_datapreped_path = self.data.y_path.with_suffix("").append("_datapreped").with_suffix(y_suffix)
 
-        x_datapreped_path.write(x)
-        y_datapreped_path.write(y)
-        self.data.x_path_to_use = x_datapreped_path
-        self.data.y_path_to_use = y_datapreped_path
+        self.data.x_datapreped_path.write(x)
+        self.data.y_datapreped_path.write(y)
 
     def dataprep_method(self, x: pd.DataFrame, y: pd.DataFrame) -> Tuple[pd.DataFrame, pd.DataFrame]:
         """To be implemented in daughter class.
@@ -54,9 +52,9 @@ class DataPrep:
 
 
 class BinFeaturesDataPrep(DataPrep):
-    """Overloads DataPrep class
+    """Overloads DataPrep class. Bins each feature columns in 'nbins' modalities. Does not modify y.
 
-    Bins each feature columns in 'nbins' modalities. Does not modify y.
+    Can be used by giving *binfeatures* as *dataprep* configuration when creating a `ifra.node.Node`
 
     Attributes
     ----------
