@@ -4,18 +4,18 @@ import pandas as pd
 
 
 class Predictor:
-    """Class to overload. Implements the notion of ruleset's prediction."""
+    """Class to overload. Implements the notion of model's prediction."""
 
-    def __init__(self, ruleset: RuleSet, **kwargs):
+    def __init__(self, model: RuleSet, **kwargs):
         """
 
         Parameters
         ----------
-        ruleset: RuleSet
+        model: RuleSet
         kwargs:
             Any additionnal keyword argument that the overleading class accepts. Those arguments will become attributes.
         """
-        self.ruleset = ruleset
+        self.model = model
         for arg in kwargs:
             setattr(self, arg, kwargs[arg])
 
@@ -25,17 +25,17 @@ class Predictor:
 
 
 class ClassificationPredictor(Predictor):
-    def __init__(self, ruleset: RuleSet):
-        if ruleset.rule_type != ClassificationRule:
+    def __init__(self, model: RuleSet):
+        if model.rule_type != ClassificationRule:
             raise TypeError("ClassificationPredictor can only be used on classification rules")
-        super().__init__(ruleset)
+        super().__init__(model)
 
 
 class RegressionPredictor(Predictor):
-    def __init__(self, ruleset: RuleSet):
-        if ruleset.rule_type != RegressionRule:
+    def __init__(self, model: RuleSet):
+        if model.rule_type != RegressionRule:
             raise TypeError("RegressionPredictor can only be used on regression rules")
-        super().__init__(ruleset)
+        super().__init__(model)
 
 
 class EquallyWeightedClassificator(ClassificationPredictor):
@@ -46,17 +46,17 @@ class EquallyWeightedClassificator(ClassificationPredictor):
     """
 
     def predict(self, x: pd.DataFrame) -> pd.Series:
-        if len(self.ruleset) == 0:
+        if len(self.model) == 0:
             return pd.Series(index=x.index)
-        self.ruleset.calc_activation(x)
-        if isinstance(self.ruleset[0].prediction, str):
+        self.model.calc_activation(x)
+        if isinstance(self.model[0].prediction, str):
             most_freq_pred = pd.concat(
-                [r.predict(x) for r in self.ruleset], axis=1
+                [r.predict(x) for r in self.model], axis=1
             ).fillna(value=np.nan).replace("nan", np.nan).T.mode()
         else:
-            most_freq_pred = pd.concat([r.predict(x) for r in self.ruleset], axis=1).T.mode()
+            most_freq_pred = pd.concat([r.predict(x) for r in self.model], axis=1).T.mode()
         most_freq_pred = most_freq_pred.loc[:, most_freq_pred.count() == 1].dropna().T.squeeze()
-        if isinstance(self.ruleset[0].prediction, str):
+        if isinstance(self.model[0].prediction, str):
             return most_freq_pred.reindex(x.index).fillna("nan")
         else:
             return most_freq_pred.reindex(x.index)
@@ -70,19 +70,19 @@ class CriterionWeightedClassificator(ClassificationPredictor):
     """
 
     def predict(self, x: pd.DataFrame) -> pd.Series:
-        if len(self.ruleset) == 0:
+        if len(self.model) == 0:
             return pd.Series(index=x.index)
-        self.ruleset.calc_activation(x)
-        if isinstance(self.ruleset[0].prediction, str):
+        self.model.calc_activation(x)
+        if isinstance(self.model[0].prediction, str):
             predictions = pd.concat(
-                [r.predict(x) for r in self.ruleset], axis=1
+                [r.predict(x) for r in self.model], axis=1
             ).fillna(value=np.nan).replace("nan", np.nan)
         else:
-            predictions = pd.concat([r.predict(x) for r in self.ruleset], axis=1)
+            predictions = pd.concat([r.predict(x) for r in self.model], axis=1)
 
         predictions.columns = pd.RangeIndex(0, len(predictions.columns))
         criterions = pd.DataFrame(
-            [[r.criterion for r in self.ruleset] for _ in x.index], index=x.index
+            [[r.criterion for r in self.model] for _ in x.index], index=x.index
         ).fillna(value=np.nan).dropna(how="all")
         if criterions.empty:
             raise ValueError("No rules had evaluated criterion : can not use CriterionWeightedRegressor")
@@ -94,7 +94,7 @@ class CriterionWeightedClassificator(ClassificationPredictor):
         predictions = predictions[mask]
         most_freq_pred = predictions.T.mode()
         most_freq_pred = most_freq_pred.loc[:, most_freq_pred.count() == 1].dropna().T.squeeze()
-        if isinstance(self.ruleset[0].prediction, str):
+        if isinstance(self.model[0].prediction, str):
             return most_freq_pred.reindex(x.index).fillna("nan")
         else:
             return most_freq_pred.reindex(x.index)
@@ -108,9 +108,9 @@ class EquallyWeightedRegressor(RegressionPredictor):
     """
 
     def predict(self, x: pd.DataFrame) -> pd.Series:
-        if len(self.ruleset) == 0:
+        if len(self.model) == 0:
             return pd.Series(index=x.index)
-        return pd.concat([r.predict(x) for r in self.ruleset], axis=1).mean(axis=1)
+        return pd.concat([r.predict(x) for r in self.model], axis=1).mean(axis=1)
 
 
 class CriterionWeightedRegressor(RegressionPredictor):
@@ -121,13 +121,13 @@ class CriterionWeightedRegressor(RegressionPredictor):
     """
 
     def predict(self, x: pd.DataFrame) -> pd.Series:
-        if len(self.ruleset) == 0:
+        if len(self.model) == 0:
             return pd.Series(index=x.index)
-        self.ruleset.calc_activation(x)
-        predictions = pd.concat([r.predict(x) for r in self.ruleset], axis=1)
+        self.model.calc_activation(x)
+        predictions = pd.concat([r.predict(x) for r in self.model], axis=1)
         predictions.columns = pd.RangeIndex(0, len(predictions.columns))
         criterions = pd.DataFrame(
-            [[r.criterion for r in self.ruleset] for _ in x.index], index=x.index
+            [[r.criterion for r in self.model] for _ in x.index], index=x.index
         ).fillna(value=np.nan).dropna(how="all")
         if criterions.empty:
             raise ValueError("No rules had evaluated criterion : can not use CriterionWeightedRegressor")
